@@ -29,14 +29,18 @@
 #include "ephy-debug.h"
 #include "ephy-dnd.h"
 #include "ephy-gui.h"
+#include "ephy-lib-type-builtins.h"
 #include "ephy-signal-accumulator.h"
 
-#include <libsoup/soup.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <string.h>
+#if 0
+/* FIXME: Refactor the DNS prefetch, this is a layering violation */
+#include <libsoup/soup.h>
 #include <webkit2/webkit2.h>
+#endif
 
 /**
  * SECTION:ephy-location-entry
@@ -50,7 +54,6 @@
 
 struct _EphyLocationEntryPrivate
 {
-	GIcon *lock_gicon;
 	GdkPixbuf *favicon;
 	GtkTreeModel *model;
 	GtkEntryCompletion *completion;
@@ -78,7 +81,6 @@ struct _EphyLocationEntryPrivate
 	guint original_address : 1;
 	guint apply_colors : 1;
 	guint needs_reset : 1;
-	guint show_lock : 1;
 	guint show_favicon : 1;
 
 	GtkTargetList *drag_targets;
@@ -110,8 +112,7 @@ enum
 	PROP_0,
 	PROP_LOCATION,
 	PROP_FAVICON,
-	PROP_LOCK_STATE,
-	PROP_SHOW_LOCK,
+	PROP_SECURITY_LEVEL,
 	PROP_SHOW_FAVICON
 };
 
@@ -145,13 +146,9 @@ ephy_location_entry_set_property (GObject *object,
 		ephy_location_entry_set_favicon (entry,
 						 g_value_get_object (value));
 		break;
-	case PROP_LOCK_STATE:
-		ephy_location_entry_set_lock_state (entry,
-						    g_value_get_enum (value));
-		break;
-	case PROP_SHOW_LOCK:
-		ephy_location_entry_set_show_lock (entry,
-						   g_value_get_boolean (value));
+	case PROP_SECURITY_LEVEL:
+		ephy_location_entry_set_security_level (entry,
+							g_value_get_enum (value));
 		break;
 	case PROP_SHOW_FAVICON:
 		ephy_location_entry_set_show_favicon (entry,
@@ -197,11 +194,6 @@ ephy_location_entry_finalize (GObject *object)
 	{
 		g_object_unref (priv->favicon);
 	}
-	
-	if (priv->lock_gicon)
-	{
-		g_object_unref (priv->lock_gicon);
-	}
 
 	G_OBJECT_CLASS (ephy_location_entry_parent_class)->finalize (object);
 }
@@ -256,32 +248,19 @@ ephy_location_entry_class_init (EphyLocationEntryClass *klass)
 							      G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
 	/**
-	* EphyLocationEntry:lock-state:
+	* EphyLocationEntry:security-level:
 	*
 	* State of the security icon.
 	*/
 	g_object_class_install_property (object_class,
-					 PROP_LOCK_STATE,
-					 g_param_spec_enum  ("lock-state",
-							     "Lock state",
+					 PROP_SECURITY_LEVEL,
+					 g_param_spec_enum  ("security-level",
+							     "Security level",
 							     "State of the security icon",
-							     EPHY_TYPE_LOCATION_LOCK_STATE,
-							     EPHY_LOCATION_LOCK_STATE_UNKNOWN,
+							     EPHY_TYPE_SECURITY_LEVEL,
+							     EPHY_SECURITY_LEVEL_NO_SECURITY,
 							     G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-	/**
-	* EphyLocationEntry:show-lock:
-	*
-	* If we should show the security icon.
-	*/
-	g_object_class_install_property (object_class,
-					 PROP_SHOW_LOCK,
-					 g_param_spec_boolean ("show-lock",
-							       "Show Lock",
-							       "If we should show the security icon",
-							       FALSE,
-							       G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-
 	g_object_class_install_property (object_class,
 					 PROP_SHOW_FAVICON,
 					 g_param_spec_boolean ("show-favicon",
@@ -969,7 +948,6 @@ ephy_location_entry_init (EphyLocationEntry *le)
 	p->user_changed = FALSE;
 	p->block_update = FALSE;
 	p->saved_text = NULL;
-	p->show_lock = FALSE;
 	p->show_favicon = TRUE;
 	p->dns_prefetch_handler = 0;
 
@@ -982,6 +960,8 @@ ephy_location_entry_new (void)
 	return GTK_WIDGET (g_object_new (EPHY_TYPE_LOCATION_ENTRY, NULL));
 }
 
+#if 0
+/* FIXME: Refactor the DNS prefetch, this is a layering violation */
 typedef struct {
 	SoupURI *uri;
 	EphyLocationEntry *entry;
@@ -998,10 +978,10 @@ free_prefetch_helper (PrefetchHelper *helper)
 static gboolean
 do_dns_prefetch (PrefetchHelper *helper)
 {
-	WebKitWebContext *context = webkit_web_context_get_default ();
+	EphyEmbedShell *shell = ephy_embed_shell_get_default ();
 
 	if (helper->uri)
-		webkit_web_context_prefetch_dns (context, helper->uri->host);
+		webkit_web_context_prefetch_dns (ephy_embed_shell_get_web_context (shell), helper->uri->host);
 
 	helper->entry->priv->dns_prefetch_handler = 0;
 
@@ -1033,6 +1013,7 @@ schedule_dns_prefetch (EphyLocationEntry *entry, guint interval, const gchar *ur
 				    (GDestroyNotify) free_prefetch_helper);
 	g_source_set_name_by_id (entry->priv->dns_prefetch_handler, "[epiphany] do_dns_prefetch");
 }
+#endif
 
 static gboolean
 cursor_on_match_cb  (GtkEntryCompletion *completion,
@@ -1056,7 +1037,10 @@ cursor_on_match_cb  (GtkEntryCompletion *completion,
 	gtk_editable_set_position (GTK_EDITABLE (entry), -1);
 	le->priv->block_update = FALSE;
 
+#if 0
+/* FIXME: Refactor the DNS prefetch, this is a layering violation */
 	schedule_dns_prefetch (le, 250, (const gchar*) url);
+#endif
 
 	g_free (url);
 
@@ -1592,72 +1576,26 @@ ephy_location_entry_set_show_favicon (EphyLocationEntry *entry,
 }
 
 /**
- * ephy_location_entry_set_show_lock:
+ * ephy_location_entry_set_security_level:
  * @entry: an #EphyLocationEntry widget
- * @show_lock: if @entry should show a lock icon indicating the security level
- * of the page
+ * @state: the #EphySecurityLevel
  *
- * If @show_lock is TRUE, the location bar will show an icon reflecting the
- * security level of the page, by default it's shown only in secure and
- * insecure pages (insecure meaning secure pages with something broken in such
- * security)
+ * Set the lock icon to be displayed
  *
  **/
 void
-ephy_location_entry_set_show_lock (EphyLocationEntry *entry,
-				   gboolean show_lock)
+ephy_location_entry_set_security_level (EphyLocationEntry *entry,
+				        EphySecurityLevel security_level)
+
 {
-	EphyLocationEntryPrivate *priv;
+	const char *icon_name;
 
 	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
 
-	priv = entry->priv;
-
-	priv->show_lock = show_lock != FALSE;
-
-	gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry),
-				       GTK_ENTRY_ICON_SECONDARY,
-				       show_lock ? priv->lock_gicon : NULL);
-}
-
-/**
- * ephy_location_entry_set_lock_state:
- * @entry: an #EphyLocationEntry widget
- * @state: the #EphyLocationLockState
- *
- * Set the lock icon to be displayed, to actually show the icon see 
- * ephy_location_entry_set_show_lock.
- *
- **/
-void
-ephy_location_entry_set_lock_state (EphyLocationEntry *entry,
-				    EphyLocationLockState state)
-
-{
-	EphyLocationEntryPrivate *priv;
-
-	g_return_if_fail (EPHY_IS_LOCATION_ENTRY (entry));
-
-	priv = entry->priv;
-
-	if (priv->lock_gicon)
-		g_object_unref (priv->lock_gicon);
-
-	/* At the moment we basically only show two kinds of
-	 * locks. Full/green for secure sites, Broken/red for sites
-	 * that are supposed to be secure but have some issues in
-	 * their security infrastructure (broken cert, etc). For
-	 * everything else, nothing is shown.
-	 */
-	if (state == EPHY_LOCATION_LOCK_STATE_SECURE)
-		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("channel-secure-symbolic");
-	else
-		priv->lock_gicon = g_themed_icon_new_with_default_fallbacks ("channel-insecure-symbolic");
-
-	if (priv->show_lock)
-		gtk_entry_set_icon_from_gicon (GTK_ENTRY (entry),
-					       GTK_ENTRY_ICON_SECONDARY,
-					       priv->lock_gicon);
+	icon_name = ephy_security_level_to_icon_name (security_level);
+	gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry),
+					   GTK_ENTRY_ICON_SECONDARY,
+					   icon_name);
 }
 
 /**
