@@ -17,10 +17,15 @@
  *
  */
 
+#ifndef POPUP_COMMANDS_H
+#define POPUP_COMMANDS_H
+
 #include <gtk/gtk.h>
 
 #include "ephy-window.h"
 
+G_BEGIN_DECLS
+
 void popup_cmd_link_in_new_window	(GtkAction *action,
 					 EphyWindow *window);
 
@@ -57,3 +62,18 @@ void popup_cmd_download_link		(GtkAction *action,
 void popup_cmd_save_image_as		(GtkAction *action,
 					 EphyWindow *window);
 
+void popup_cmd_media_in_new_window      (GtkAction *action,
+                                         EphyWindow *window);
+
+void popup_cmd_media_in_new_tab         (GtkAction *action,
+                                         EphyWindow *window);
+
+void popup_cmd_copy_media_location      (GtkAction *action,
+                                         EphyWindow *window);
+
+void popup_cmd_save_media_as            (GtkAction *action,
+                                         EphyWindow *window);
+
+G_END_DECLS
+
+#endif
